Files
odfstudio/include/xmloff
Noel Grandin 349919440b tdf#107592 Impress PPS save to ODP slow
Takes the time from 20s to 5s on my PC.

Change-Id: Iea7a94ee9fbe068b69a770fd9201e73646be59b9
Reviewed-on: https://gerrit.libreoffice.org/72140
Tested-by: Jenkins
Reviewed-by: Noel Grandin <noel.grandin@collabora.co.uk>
2019-05-13 13:23:00 +02:00
..
2019-03-14 14:04:54 +01:00
…
2018-09-13 12:56:39 +02:00
2019-03-26 07:30:13 +01:00
2018-09-13 12:56:39 +02:00
2019-03-14 14:04:54 +01:00
2019-03-09 07:28:18 +01:00
2019-03-16 07:17:15 +01:00